@@ -18,6 +18,7 @@ our @EXPORT = qw/
   req
   res
   template
+  module
   /;
 
 our $app;
@@ -80,6 +81,7 @@ sub res      { $app->res }
 sub template { $app->res->template(@_) }
 sub debug    { $app->debug(@_) }
 sub error    { $app->error(@_) }
+sub module   { $app->load_module(@_) }
 
 1;
 
@@ -315,6 +317,12 @@ currently loaded template module.
 
 Creates and returns a PSGI ready subroutine, and makes the app ready for C<Plack>.
 
+=head2 module
+
+Loads a Kelp module. The module options may be specified after the module name.
+
+    module 'JSON::XS', pretty => 1;
+
 =head1 TESTING
 
 When writing a C<Kelp::Less> app, we don't have a separate class to initialize and
